@@ -18,10 +18,6 @@
 #' plot(out)
 #' @export
 #' @method plot corranalysis
-#' @importFrom ggplotify as.ggplot
-#' @importFrom network network
-#' @importFrom network set.edge.attribute
-#' @importFrom network "%e%"
 #' @importFrom GGally ggnet2
 #' @importFrom grDevices colorRampPalette
 #' @importFrom graphics par
@@ -38,11 +34,6 @@
 #' @importFrom corrplot corrMatOrder
 #' @importFrom corrplot corrRect.hclust
 #' @importFrom corrplot colorlegend
-#' @importFrom ggnetwork geom_nodes
-#' @importFrom ggnetwork geom_edges
-#' @importFrom ggnetwork ggnetwork
-#' @importFrom ggnetwork theme_blank
-#' @importFrom ggnetwork geom_nodetext_repel
 #' @importFrom ggplot2 scale_alpha
 #' @importFrom ggplot2 aes_string
 #' @importFrom ggplot2 scale_colour_gradientn
@@ -58,6 +49,19 @@ plot.corranalysis <- function(x, horizontal = TRUE, title = NULL, ...) {
     corr_plot(cor_mtx, type = "lower", method = "number", diag = F, add = T, tl.pos = "n", cl.pos = "n", p.mat = cor_mtest$p, sig.level = sl)
   }
 
+  if (!requireNamespace("ggnetwork", quietly = TRUE)) {
+    stop("Package 'ggnetwork' is required for plotting. Please install it.", call. = FALSE)
+  }
+
+  if (!requireNamespace("network", quietly = TRUE)) {
+    stop("The 'network' package is required to use '%e%'. Please install it.", call. = FALSE)
+  }
+  `%e%` <- get("%e%", envir = asNamespace("network"))
+
+  if (!requireNamespace("ggplotify", quietly = TRUE)) {
+    stop("Package 'ggplotify' is required for plotting. Please install it.", call. = FALSE)
+  }
+
   if (!is.corranalysis(x)) {
     stop("Not a 'corranalysis' object")
   }
@@ -90,7 +94,7 @@ plot.corranalysis <- function(x, horizontal = TRUE, title = NULL, ...) {
       ggnetwork::geom_nodes(shape=21, fill="#D6EAF877", color="#3498DB77", size=15) +
       ggnetwork::geom_edges(aes(color=edge.color), size=1.5) +
       scale_colour_gradientn("", colors = cols, limits=c(-1,1)) +
-      scale_alpha(guide=FALSE) +
+      scale_alpha(guide='none') +
       ggnetwork::geom_nodetext_repel(aes(label=vertex.names)) +
       ggnetwork::theme_blank()
   } else {
